% Figure1_7.m
% It requires the following functions:
% heun2(.m
% trapezoidal2.m
% spTVT2.m
% fKepler.m
% fKeplerT.m
% fKeplerV.m
% phiKepler
%
% midpoint2.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial and final time, and  Time step
global h
t0=0;  tf=100;   N=1*1000;  N2=N/2; t=[];
h = (tf-t0)/N;
% Initial Conditions 
e=0.;   x0 = [1-e ; 0; 0; sqrt((1+e)/(1-e))];
q0=[x0(1); x0(2)];  p0=[x0(3); x0(4)]; 
% Energy at initial conditions
H0=((x0(3))^2+(x0(4))^2)/2-1/(sqrt((x0(1))^2+(x0(2))^2));

[t2 x2]=heun2(@fKepler,t0,tf,x0,N);
[t2 xt2]=trapezoidal2(@fKepler,t0,tf,x0,N);
[t q2 p2]=spTVT2(@fKeplerT,@fKeplerV,t0,tf,q0,p0,N);
[t q2m p2m]=spTVT2m(@fKeplerT,@fKeplerVm,t0,tf,q0,p0,N);
%[t2 xm2]=midpoint2(@fKepler,t0,tf,x0,N2);

 x = x0';th=t0;
q0(1)=x0(1);p0(1)=x0(2);q0(2)=x0(3);p0(2)=x0(4);
for i=1:N;
   th=th+h;
   [q p]=phiKepler(q0,p0,h);
   x=[x; q p];
   q0=q;p0=p;
end

eP=sqrt((x(:,1)-x2(:,1)).^2+(x(:,2)-x2(:,2)).^2+(x(:,3)-x2(:,3)).^2+(x(:,4)-x2(:,4)).^2);
ePT=sqrt((x(:,1)-xt2(:,1)).^2+(x(:,2)-xt2(:,2)).^2+(x(:,3)-xt2(:,3)).^2+(x(:,4)-xt2(:,4)).^2);
eSVT=sqrt((x(:,1)-q2(:,1)).^2+(x(:,2)-q2(:,2)).^2+(x(:,3)-p2(:,1)).^2+(x(:,4)-p2(:,2)).^2);
eSVTm=sqrt((x(:,1)-q2m(:,1)).^2+(x(:,2)-q2m(:,2)).^2+(x(:,3)-p2m(:,1)).^2+(x(:,4)-p2m(:,2)).^2);
%eSTV=sqrt((x(:,1)-q1(:,1)).^2+(x(:,2)-q1(:,2)).^2+(x(:,3)-p1(:,1)).^2+(x(:,4)-p1(:,2)).^2);

errorSVT = ((p2(:,1)).^2+(p2(:,2)).^2)./2-1./(sqrt((q2(:,1)).^2+(q2(:,2)).^2)) - H0;
errorSVTm = ((p2m(:,1)).^2+(p2m(:,2)).^2)./2-1./(sqrt((q2m(:,1)).^2+(q2m(:,2)).^2)) - H0;
errorH2 = ((x2(:,3)).^2+(x2(:,4)).^2)./2-1./(sqrt((x2(:,1)).^2+(x2(:,2)).^2)) - H0;
errorT2 = ((xt2(:,3)).^2+(xt2(:,4)).^2)./2-1./(sqrt((xt2(:,1)).^2+(xt2(:,2)).^2)) - H0;
%errorM2 = ((xm2(:,3)).^2+(xm2(:,4)).^2)./2-1./(sqrt((xm2(:,1)).^2+(xm2(:,2)).^2)) - H0;

figure(2)
 
 subplot(1,2,1)
  hold on
  plot(log10(t),log10(abs(errorH2(:))),':k','LineWidth',1.5,'Color',[0 0 0]+0.7)
  plot(log10(t),log10(abs(errorT2(:))),'-k','LineWidth',1.5,'Color',[0 0 0]+0.9)
  plot(log10(t),log10(abs(errorSVT(:))),'k--','LineWidth',1.5,'Color',[0 0 0]+0.0)
 plot(log10(t),log10(abs(errorSVTm(:))),'k-','LineWidth',1.5,'Color',[0 0 0]+0)
  axis([-1 2 -14 -3]) 
  xlabel('{\fontsize{14} log_{10}(t) }')   
  ylabel('{\fontsize{14} log_{10}|H(t)-H_0|}')   
  box
  text(-0.7,-4,'H_2','FontSize',12)
  text(-0.7,-6,'S_2','FontSize',12)
  text(-0.5,-9,'S_2m','FontSize',12)
  text(-0.5,-12.5,'T_2','FontSize',12)

 subplot(1,2,2)
  hold on
  plot(log10(t),log10(eP),':k','LineWidth',1.5,'Color',[0 0 0]+0.7)
  plot(log10(t),log10(ePT),'-k','LineWidth',1.5,'Color',[0 0 0]+0.9)
  plot(log10(t),log10(eSVT),'--k','LineWidth',1.5,'Color',[0 0 0]+0.0)
 plot(log10(t),log10(eSVTm),'-k','LineWidth',1.5,'Color',[0 0 0]+0)
  axis([-1 2 -4.5 0.5]) 
  xlabel('{\fontsize{14} log_{10}(t) }')   
  ylabel('{\fontsize{14} log_{10}(err(q,p))}')   
  box
  text(1,0,'H_2','FontSize',12)
  text(0.5,-2,'S_2','FontSize',12)
  text(1,-2.2,'T_2','FontSize',12)
  text(0.1,-4,'S_2m','FontSize',12)
